@@ -35,8 +35,10 @@ def notify(title, subtitle=None, info_text=None, identity_image=None, content_im
   # content_image is the image on the right side
   if content_image:
     content_image_path = f'file:{os.getcwd()}/{content_image}'
+    print(content_image_path)
     url = NSURL.alloc().initWithString_(content_image_path)
     image = NSImage.alloc().initWithContentsOfURL_(url)
+    print(image)
     notification.setContentImage_(image)
 
   if sound:
